@@ -1,24 +1,16 @@
 from __future__ import annotations
 
 import ast
+import os
 import sys
 from collections import abc
 from copy import deepcopy
 from pathlib import Path
 from types import MappingProxyType
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Mapping,
-    Sequence,
-    Tuple,
-    Union,
-    get_args,
-    get_origin,
-)
+from typing import Any, Callable, Dict, Mapping, Sequence, Tuple, Union
 
 import yaml
+from typing_extensions import get_args, get_origin
 
 from .attrdict import AttrDict, is_mapping
 from .utils import Scalar, Struct, get_time_stamp, hash_string, sanitize_filename
@@ -214,7 +206,7 @@ class Config(AttrDict):
     def from_dir(cls, dirname: Union[str, Path], file_ending: str = ".cfg") -> Config:
         dirname = Path(dirname)
         files = dirname.glob("*" + file_ending)
-        key_file_dict = {f.stem: f for f in files}
+        key_file_dict = {f.stem: f for f in sorted(files)}
         return cls.from_key_file_dict(key_file_dict)
 
     @classmethod
@@ -380,8 +372,10 @@ class Config(AttrDict):
 
     def __str__(self):
         add_dump_info = {Config.CFG_ID_TOKEN: self.get_cfg_id()}
+        dump_dict = add_dump_info
+        dump_dict.update(self)
         return yaml.safe_dump(
-            add_dump_info | self,
+            dump_dict,
             default_flow_style=False,
             sort_keys=False,
         )
@@ -424,10 +418,10 @@ class Config(AttrDict):
                     "destination '%s' for description symlink already exists but is not"
                     " a symlink" % dst
                 )
-            if dst.readlink() != src:
+            if Path(os.readlink(dst)) != src:
                 raise EnvironmentError(
                     "destination '%s' for description symlink already exists, but is"
-                    " linked to a different target '%s'" % (dst, dst.readlink())
+                    " linked to a different target '%s'" % (dst, Path(os.readlink(dst)))
                 )
             return
         dst.symlink_to(src)
